@@ -379,16 +379,16 @@ class asymptotic_fit(plotting, asymp_spec_model):
         """
         self.developer_mode = developer_mode
         
-        if method not in ['mcmc', 'nested']:
+        if method not in ['emcee', 'cpnest']:
             warnings.warn(f'Method {method} not found: Using method mcmc')
-            method = 'mcmc'
+            method = 'emcee'
 
-        if method == 'mcmc':
+        if method == 'emcee':
             self.fit = pb.mcmc(np.median(self.start_samples, axis=0),
                                self.likelihood, self.prior)
             self.fit(start_samples=self.start_samples)
 
-        elif method == 'nested':
+        elif method == 'cpnest':
             #bounds = [[self.start_samples[:, n].min(), 
             #           self.start_samples[:, n].max()] for n in range(len(self.par_names))]
             bounds = [[self.prior_data[key].min(), self.prior_data[key].max()] for key in self.par_names]
