@@ -709,15 +709,15 @@ class session():
 
         # Take whatever is in the timeseries column of vardf and make it an
         # lk.lightcurve object or None
-
         _lc_to_lk(vardf, download_dir, use_cached=use_cached)
         
         # Take whatever is in the timeseries column of vardf and turn it into
         # a periodogram object in the periodogram column.
-
         _lk_to_pg(vardf)
 
 
+       
+
         for i in range(len(vardf)):
             self.stars.append(star(ID=vardf.loc[i, 'ID'],
                                    pg=vardf.loc[i, 'psd'],
@@ -732,8 +732,8 @@ class session():
                 warnings.warn("Input numax is greater than Nyquist frequeny for %s" % (st.ID))
 
     def __call__(self, bw_fac=1, norders=8, model_type='simple', tune=1500, 
-                 nthreads=1, verbose=False, make_plots=False, store_chains=False 
-                 ):
+                 nthreads=1, verbose=False, make_plots=False, store_chains=False, 
+                 asy_sampling='emcee', developer_mode=False):
         """ Call all the star class instances
 
         Once initialized, calling the session class instance will loop through
@@ -761,22 +761,32 @@ class session():
             Whether or not to produce plots of the results. Default is False.            
         store_chains : bool, optional.
             Whether or not to store MCMC chains on disk. Default is False.
+        asy_sampling : string
+            Method to be used for sampling the posterior in asy_peakbag. Options
+            are 'emcee' or 'cpnest'. Default method is 'emcee' that will call 
+            emcee, alternative is 'cpnest' to call nested sampling with CPnest.    
+        developer_mode : bool
+            Run asy_peakbag in developer mode. Currently just retains the input 
+            value of dnu and numax as priors, for the purposes of expanding
+            the prior sample. Important: This is not good practice for getting 
+            science results!    
             
         """
         
         self.pb_model_type = model_type
 
         for i, st in enumerate(self.stars):
-            try:
-                st(bw_fac=bw_fac, tune=tune, norders=norders, 
-                   model_type=self.pb_model_type, make_plots=make_plots, 
-                   store_chains=store_chains, nthreads=nthreads)
-                
-                self.stars[i] = None
+            #try:
+            st(bw_fac=bw_fac, tune=tune, norders=norders, 
+               model_type=self.pb_model_type, make_plots=make_plots, 
+               store_chains=store_chains, nthreads=nthreads, 
+               asy_sampling=asy_sampling, developer_mode=developer_mode)
             
-            # Crude way to send error messages that occur in star up to Session 
-            # without ending the session. Is there a better way?
-            except Exception as ex:
-                 message = "Star {0} produced an exception of type {1} occurred. Arguments:\n{2!r}".format(st.ID, type(ex).__name__, ex.args)
-                 print(message)
+            self.stars[i] = None
+            
+#            # Crude way to send error messages that occur in star up to Session 
+#            # without ending the session. Is there a better way?
+#            except Exception as ex:
+#                 message = "Star {0} produced an exception of type {1} occurred. Arguments:\n{2!r}".format(st.ID, type(ex).__name__, ex.args)
+#                 print(message)
             
